from util import Enumerator

class LSErrors(Enumerator):
    kLSUnknownErr                       = -10810
    kLSNotAnApplicationErr              = -10811
    kLSNotInitializedErr                = -10812
    kLSDataUnavailableErr               = -10813 # e.g. no kind string
    kLSApplicationNotFoundErr           = -10814 # e.g. no application claims the file
    kLSUnknownTypeErr                   = -10815
    kLSDataTooOldErr                    = -10816
    kLSDataErr                          = -10817
    kLSLaunchInProgressErr              = -10818 # e.g. opening an alreay opening application
    kLSNotRegisteredErr                 = -10819
    kLSAppDoesNotClaimTypeErr           = -10820
    kLSAppDoesNotSupportSchemeWarning   = -10821 # not an error, just a warning
    kLSServerCommunicationErr           = -10822 # cannot set recent items
    kLSCannotSetInfoErr                 = -10823 # you may not set item info for this item

class LSInfoBitmap(Enumerator):
    kLSMinCatInfoBitmap           = 0x180a # (0x2 | 0x8 | 0x800 | 0x1000) #(kFSCatInfoNodeFlags | kFSCatInfoParentDirID | kFSCatInfoFinderInfo | kFSCatInfoFinderXInfo) # minimum info needed to avoid a FSGetCatalogInfo call when fetching item information

class LSInvalidExtensionError(Enumerator):
    kLSInvalidExtensionIndex      = 0xFFFFFFFFL #(unsigned long)0xFFFFFFFF # Index returned from LSGetExtensionInfo when name has no extension

class LSRequestedInfo(Enumerator):
    kLSRequestExtension           = 0x00000001  # safe to use from threads
    kLSRequestTypeCreator         = 0x00000002  # safe to use from threads
    kLSRequestBasicFlagsOnly      = 0x00000004  # all but type of application and extension flags - safe to use from threads
    kLSRequestAppTypeFlags        = 0x00000008  # NOT SAFE to use from threads
    kLSRequestAllFlags            = 0x00000010  # NOT SAFE to use from threads
    kLSRequestIconAndKind         = 0x00000020  # NOT SAFE to use from threads
    kLSRequestExtensionFlagsOnly  = 0x00000040  # safe to use from threads
    kLSRequestAllInfo             = 0xFFFFFFFFL #(unsigned long)0xFFFFFFFF # NOT SAFE to use from threads

class LSItemInfoFlags(Enumerator):
    kLSItemInfoIsPlainFile        = 0x00000001 # none of the following applies
    kLSItemInfoIsPackage          = 0x00000002 # app, doc, or bundle package
    kLSItemInfoIsApplication      = 0x00000004 # single-file or packaged
    kLSItemInfoIsContainer        = 0x00000008 # folder or volume
    kLSItemInfoIsAliasFile        = 0x00000010 # Alias file (includes sym links)
    kLSItemInfoIsSymlink          = 0x00000020 # UNIX sym link
    kLSItemInfoIsInvisible        = 0x00000040 # does not include '.' files or '.hidden' entries
    kLSItemInfoIsNativeApp        = 0x00000080 # Carbon or Cocoa native app
    kLSItemInfoIsClassicApp       = 0x00000100 # CFM Classic app
    kLSItemInfoAppPrefersNative   = 0x00000200 # Carbon app that prefers to be launched natively
    kLSItemInfoAppPrefersClassic  = 0x00000400 # Carbon app that prefers to be launched in Classic
    kLSItemInfoAppIsScriptable    = 0x00000800 # App can be scripted
    kLSItemInfoIsVolume           = 0x00001000 # item is a volume
    kLSItemInfoExtensionIsHidden  = 0x00100000 # item has a hidden extension

class LSRolesMask(Enumerator):
    kLSRolesNone                  = 0x00000001  # no claim is made about support for this type/scheme
    kLSRolesViewer                = 0x00000002  # claim to be able to view this type/scheme
    kLSRolesEditor                = 0x00000004  # claim to be able to edit this type/scheme
    kLSRolesAll                   = 0xFFFFFFFFL #(unsigned long)0xFFFFFFFF # claim to do it all

class LSKindID(Enumerator):
    kLSUnknownKindID              = 0

class LSUnknownTypeOrCreator(Enumerator):
    kLSUnknownType                = 0
    kLSUnknownCreator             = 0

class LSAcceptanceFlags(Enumerator):
    kLSAcceptDefault              = 0x00000001
    kLSAcceptAllowLoginUI         = 0x00000002 # show UI to log in if necessary

class LSLaunchFlags(Enumerator):
    kLSLaunchDefaults             = 0x00000001  # default = open, async, use Info.plist, start Classic
    kLSLaunchAndPrint             = 0x00000002  # print items instead of open them
    kLSLaunchReserved2            = 0x00000004
    kLSLaunchReserved3            = 0x00000008
    kLSLaunchReserved4            = 0x00000010
    kLSLaunchReserved5            = 0x00000020
    kLSLaunchReserved6            = 0x00000040
    kLSLaunchInhibitBGOnly        = 0x00000080  # causes launch to fail if target is background-only.
    kLSLaunchDontAddToRecents     = 0x00000100  # do not add app or documents to recents menus.
    kLSLaunchDontSwitch           = 0x00000200  # don't bring new app to the foreground.
    kLSLaunchNoParams             = 0x00000800  # Use Info.plist to determine launch parameters
    kLSLaunchAsync                = 0x00010000  # launch async obtain results from kCPSNotifyLaunch.
    kLSLaunchStartClassic         = 0x00020000  # start up Classic environment if required for app.
    kLSLaunchInClassic            = 0x00040000  # force app to launch in Classic environment.
    kLSLaunchNewInstance          = 0x00080000  # Instantiate app even if it is already running.
    kLSLaunchAndHide              = 0x00100000  # Send child a "hide" request as soon as it checks in.
    kLSLaunchAndHideOthers        = 0x00200000  # Hide all other apps when child checks in.

_globals = globals()
for _v in _globals.values():
    if isinstance(_v, type) and issubclass(_v, Enumerator):
        _globals.update(_v.__keys__)
del _globals, _v
