cdef extern from "<ApplicationServices/ApplicationServices.h>":
    cdef enum LSErrorFlags:
        kLSUnknownErr                       = -10810
        kLSNotAnApplicationErr              = -10811
        kLSNotInitializedErr                = -10812
        kLSDataUnavailableErr               = -10813 # e.g. no kind string
        kLSApplicationNotFoundErr           = -10814 # e.g. no application claims the file
        kLSUnknownTypeErr                   = -10815
        kLSDataTooOldErr                    = -10816
        kLSDataErr                          = -10817
        kLSLaunchInProgressErr              = -10818 # e.g. opening an alreay opening application
        kLSNotRegisteredErr                 = -10819
        kLSAppDoesNotClaimTypeErr           = -10820
        kLSAppDoesNotSupportSchemeWarning   = -10821 # not an error, just a warning
        kLSServerCommunicationErr           = -10822 # cannot set recent items
        kLSCannotSetInfoErr                 = -10823 # you may not set item info for this item
    
    cdef enum LSInfoBitmap:
        kLSMinCatInfoBitmap           = 0x180a # (0x2 | 0x8 | 0x800 | 0x1000) #(kFSCatInfoNodeFlags | kFSCatInfoParentDirID | kFSCatInfoFinderInfo | kFSCatInfoFinderXInfo) # minimum info needed to avoid a FSGetCatalogInfo call when fetching item information
    
    cdef enum LSInvalidExtensionError:
        kLSInvalidExtensionIndex      = 0xFFFFFFFF #(unsigned long)0xFFFFFFFF # Index returned from LSGetExtensionInfo when name has no extension
    
    cdef enum LSRequestedInfo:
        kLSRequestExtension           = 0x00000001  # safe to use from threads
        kLSRequestTypeCreator         = 0x00000002  # safe to use from threads
        kLSRequestBasicFlagsOnly      = 0x00000004  # all but type of application and extension flags - safe to use from threads
        kLSRequestAppTypeFlags        = 0x00000008  # NOT SAFE to use from threads
        kLSRequestAllFlags            = 0x00000010  # NOT SAFE to use from threads
        kLSRequestIconAndKind         = 0x00000020  # NOT SAFE to use from threads
        kLSRequestExtensionFlagsOnly  = 0x00000040  # safe to use from threads
        kLSRequestAllInfo             = 0xFFFFFFFF #(unsigned long)0xFFFFFFFF # NOT SAFE to use from threads
    
    cdef enum LSItemInfoFlags:
        kLSItemInfoIsPlainFile        = 0x00000001 # none of the following applies
        kLSItemInfoIsPackage          = 0x00000002 # app, doc, or bundle package
        kLSItemInfoIsApplication      = 0x00000004 # single-file or packaged
        kLSItemInfoIsContainer        = 0x00000008 # folder or volume
        kLSItemInfoIsAliasFile        = 0x00000010 # Alias file (includes sym links)
        kLSItemInfoIsSymlink          = 0x00000020 # UNIX sym link
        kLSItemInfoIsInvisible        = 0x00000040 # does not include '.' files or '.hidden' entries
        kLSItemInfoIsNativeApp        = 0x00000080 # Carbon or Cocoa native app
        kLSItemInfoIsClassicApp       = 0x00000100 # CFM Classic app
        kLSItemInfoAppPrefersNative   = 0x00000200 # Carbon app that prefers to be launched natively
        kLSItemInfoAppPrefersClassic  = 0x00000400 # Carbon app that prefers to be launched in Classic
        kLSItemInfoAppIsScriptable    = 0x00000800 # App can be scripted
        kLSItemInfoIsVolume           = 0x00001000 # item is a volume
        kLSItemInfoExtensionIsHidden  = 0x00100000 # item has a hidden extension
    
    cdef enum LSRolesMask:
        kLSRolesNone                  = 0x00000001  # no claim is made about support for this type/scheme
        kLSRolesViewer                = 0x00000002  # claim to be able to view this type/scheme
        kLSRolesEditor                = 0x00000004  # claim to be able to edit this type/scheme
        kLSRolesAll                   = 0xFFFFFFFF #(unsigned long)0xFFFFFFFF # claim to do it all

    cdef enum LSKindID:
        kLSUnknownKindID              = 0
    
    cdef enum LSUnknownTypeOrCreator:
        kLSUnknownType                = 0
        kLSUnknownCreator             = 0
    
    ctypedef struct LSItemInfoRecord:
        LSItemInfoFlags     flags
        OSType              filetype
        OSType              creator                # release when finished
        CFStringRef         extension              # release when finished
        CFStringRef         iconFileName           # not for general use
        LSKindID            kindID                 # not for general use
    
    cdef enum LSAcceptanceFlags:
        kLSAcceptDefault              = 0x00000001
        kLSAcceptAllowLoginUI         = 0x00000002 # show UI to log in if necessary
    
    cdef enum LSLaunchFlags:
        kLSLaunchDefaults             = 0x00000001  # default = open, async, use Info.plist, start Classic
        kLSLaunchAndPrint             = 0x00000002  # print items instead of open them
        kLSLaunchReserved2            = 0x00000004
        kLSLaunchReserved3            = 0x00000008
        kLSLaunchReserved4            = 0x00000010
        kLSLaunchReserved5            = 0x00000020
        kLSLaunchReserved6            = 0x00000040
        kLSLaunchInhibitBGOnly        = 0x00000080  # causes launch to fail if target is background-only.
        kLSLaunchDontAddToRecents     = 0x00000100  # do not add app or documents to recents menus.
        kLSLaunchDontSwitch           = 0x00000200  # don't bring new app to the foreground.
        kLSLaunchNoParams             = 0x00000800  # Use Info.plist to determine launch parameters
        kLSLaunchAsync                = 0x00010000  # launch async obtain results from kCPSNotifyLaunch.
        kLSLaunchStartClassic         = 0x00020000  # start up Classic environment if required for app.
        kLSLaunchInClassic            = 0x00040000  # force app to launch in Classic environment.
        kLSLaunchNewInstance          = 0x00080000  # Instantiate app even if it is already running.
        kLSLaunchAndHide              = 0x00100000  # Send child a "hide" request as soon as it checks in.
        kLSLaunchAndHideOthers        = 0x00200000  # Hide all other apps when child checks in.
    
    ctypedef struct LSLaunchFSRefSpec:
        FSRef*          appRef                 # app to use, can be NULL
        UInt32          numDocs                # items to open/print, can be NULL
        FSRef*          itemRefs               # array of FSRefs
        AEDesc*         passThruParams         # passed untouched to application as optional parameter
        LSLaunchFlags   launchFlags
        void*           asyncRefCon            # used if you register for app birth/death notification
    
    ctypedef struct LSLaunchURLSpec:
        CFURLRef        appURL                 # app to use, can be NULL
        CFArrayRef      itemURLs               # items to open/print, can be NULL
        AEDesc*         passThruParams         # passed untouched to application as optional parameter
        LSLaunchFlags   launchFlags
        void*           asyncRefCon            # used if you register for app birth/death notification
    
    #
    #   LSCopyItemInfoForRef()
    #
    #   Summary:
    #     Return information about an item.
    #
    #   Discussion:
    #     Returns as much or as little information as requested about
    #     inItemRef. Some information is available in a thread-safe manner,
    #     some is not. All CFStrings must be released after use.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inItemRef:
    #       The FSRef of the item about which information is requested.
    #
    #     inWhichInfo:
    #       Flags indicating which information to return
    #
    #     outItemInfo:
    #       Information is returned in this structure. Must not be NULL
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSCopyItemInfoForRef(FSRef* inItemRef, LSRequestedInfo inWhichInfo, LSItemInfoRecord* outItemInfo)
    
    #
    #   LSCopyItemInfoForURL()
    #
    #   Summary:
    #     Return information about an item.
    #
    #   Discussion:
    #     Returns as much or as little information as requested about
    #     inURL. Some information is available in a thread-safe manner,
    #     some is not. All CFStrings must be released after use.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inURL:
    #       The CFURLRef of the item about which information is requested.
    #
    #     inWhichInfo:
    #       Flags indicating which information to return
    #
    #     outItemInfo:
    #       Information is returned in this structure. Must not be NULL
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSCopyItemInfoForURL(CFURLRef inURL, LSRequestedInfo inWhichInfo, LSItemInfoRecord* outItemInfo)
    
    #
    #   LSGetExtensionInfo()
    #
    #   Summary:
    #     Get information about the extension for a file system name.
    #
    #   Discussion:
    #     Returns the starting index of the extension (not including the
    #     period) or kLSInvalidExtensionIndex if the input name has no
    #     extension.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inNameLen:
    #       The number of the UniChars in inNameBuffer.
    #
    #     inNameBuffer:
    #       The buffer containing the name's Unicode characters.
    #
    #     outExtStartIndex:
    #       On success, the starting index of the extension if there is one
    #       (not including the period). Set to kLSInvalidExtensionIndex if
    #       inNameBuffer does not contain a valid extension.
    #
    #   Availability:
    #     Mac OS X:         in version 10.1 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSGetExtensionInfo(UniCharCount inNameLen, UniChar inNameBuffer[], UniCharCount* outExtStartIndex)
    
    #
    #   LSCopyDisplayNameForRef()
    #
    #   Summary:
    #     Get the display name for an FSRef.
    #
    #   Discussion:
    #     Return a copy of the display name for an FSRef. Takes into
    #     consideration whether this item has a hidden extension or not.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inRef:
    #       The FSRef for which the display name is desired.
    #
    #     outDisplayName:
    #       Pointer to the CFString into which the display name should be
    #       copied. Callers must dispose of the resulting CFString.
    #
    #   Availability:
    #     Mac OS X:         in version 10.1 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSCopyDisplayNameForRef(FSRef* inRef, CFStringRef* outDisplayName)
    
    #
    #   LSCopyDisplayNameForURL()
    #
    #   Summary:
    #     Get the display name for a CFURLRef.
    #
    #   Discussion:
    #     Return a copy of the display name for a CFURLRef. Takes into
    #     consideration whether this item has a hidden extension or not.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inURL:
    #       The URL for which the display name is desired.
    #
    #     outDisplayName:
    #       Pointer to the CFString into which the display name should be
    #       copied. Callers must dispose of the resulting CFString.
    #
    #   Availability:
    #     Mac OS X:         in version 10.1 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSCopyDisplayNameForURL(CFURLRef inURL, CFStringRef* outDisplayName)
    
    #
    #   LSSetExtensionHiddenForRef()
    #
    #   Summary:
    #     Sets whether the extension for an FSRef is hidden or not.
    #
    #   Discussion:
    #     Sets the necessary file system state to indicate that the
    #     extension for inRef is hidden, as in the Finder. You can
    #     determine if an FSRef's extension is hidden using
    #     LSCopyItemInfoForRef.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inRef:
    #       The FSRef for which the extension is to be hidden or shown.
    #
    #     inHide:
    #       True to hide inRef's extension, false to show it.
    #
    #   Availability:
    #     Mac OS X:         in version 10.1 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSSetExtensionHiddenForRef(FSRef* inRef, Boolean inHide)
    
    #
    #   LSSetExtensionHiddenForURL()
    #
    #   Summary:
    #     Sets whether the extension for a CFURLRef is hidden or not.
    #
    #   Discussion:
    #     Sets the necessary file system state to indicate that the
    #     extension for inURL is hidden, as in the Finder. You can
    #     determine if a CFURLRef's extension is hidden using
    #     LSCopyItemInfoForURL.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inURL:
    #       The CFURLRef for which the extension is to be hidden or shown.
    #
    #     inHide:
    #       True to hide inURL's extension, false to show it.
    #
    #   Availability:
    #     Mac OS X:         in version 10.1 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSSetExtensionHiddenForURL(CFURLRef inURL, Boolean inHide)
    
    #
    #   LSCopyKindStringForRef()
    #
    #   Summary:
    #     Get the kind string for an item.
    #
    #   Discussion:
    #     Returns the kind string as used in the Finder and elsewhere for
    #     inFSRef. The CFStringRef must be released after use.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inFSRef:
    #       The item for which the kind string is requested.
    #
    #     outKindString:
    #       A CFStringRef* to receive the copied kind string object. This
    #       CFStringRef must be released eventually.
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSCopyKindStringForRef(FSRef* inFSRef, CFStringRef* outKindString)
    
    #
    #   LSCopyKindStringForURL()
    #
    #   Summary:
    #     Get the kind string for an item.
    #
    #   Discussion:
    #     Returns the kind string as used in the Finder and elsewhere for
    #     inURL. The CFStringRef must be released after use.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inURL:
    #       The item for which the kind string is requested.
    #
    #     outKindString:
    #       A CFStringRef* to receive the copied kind string object. This
    #       CFStringRef must be released eventually.
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSCopyKindStringForURL(CFURLRef inURL, CFStringRef* outKindString)
    
    #
    #   LSCopyKindStringForTypeInfo()
    #
    #   Summary:
    #     Return the kind string for items like the provided info
    #
    #   Discussion:
    #     Returns the kind string as shown in the Finder for the those
    #     items whose type, creator, and/or extension match the provided
    #     information. The kind string returned will be the one that most
    #     closely describes all the information provided. The kind string
    #     is subject to the document binding preferences that have been
    #     specified by the user. For example, if a creator is specified but
    #     the user has asked for files with the given
    #     creator/type/extension combination to open in an application with
    #     a different creator, the kind string will be loaded from the
    #     user's preferred application.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inType:
    #       The OSType file type for which you want a kind string. Specify
    #       kLSUnknownType if no file type information is available.
    #
    #     inCreator:
    #       The OSType creator for which you want a kind string. Specify
    #       kLSUnknownCreator if no creator information is available.
    #
    #     inExtension:
    #       The extension for which you want a kind string. Specify NULL if
    #       no extension information is available.
    #
    #     outKindString:
    #       A CFStringRef* to receive the copied kind string object. This
    #       CFStringRef must be released eventually.
    #
    #   Availability:
    #     Mac OS X:         in version 10.2 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSCopyKindStringForTypeInfo(OSType inType, OSType inCreator, CFStringRef inExtension, CFStringRef* outKindString)
    
    #
    #   LSCopyKindStringForMIMEType()
    #
    #   Summary:
    #     Get the kind string for the specified MIME type.
    #
    #   Discussion:
    #     Returns the localized kind string describing the specified MIME
    #     type.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inMIMEType:
    #       The string specifying the MIME type.
    #
    #     outKindString:
    #       A CFStringRef* to receive the copied kind string object. This
    #       CFStringRef must be released eventually.
    #
    #   Availability:
    #     Mac OS X:         in version 10.2 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSCopyKindStringForMIMEType(CFStringRef inMIMEType, CFStringRef* outKindString)
    
    #
    #   LSGetApplicationForItem()
    #
    #   Summary:
    #     Return the application used to open an item.
    #
    #   Discussion:
    #     Consults the binding tables to return the application that would
    #     be used to open inItemRef if it were double-clicked in the
    #     Finder. This application will be the user-specified override if
    #     appropriate or the default otherwise. If no application is known
    #     to LaunchServices suitable for opening this item,
    #     kLSApplicationNotFoundErr will be returned.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inItemRef:
    #       The FSRef of the item for which the application is requested.
    #
    #     inRoleMask:
    #       Whether to return the editor or viewer for inItemRef. If you
    #       don't care which, use kLSRolesAll.
    #
    #     outAppRef:
    #       Filled in with the FSRef of the application if not NULL.
    #
    #     outAppURL:
    #       Filled in with the CFURLRef of the application if not NULL.
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSGetApplicationForItem(FSRef* inItemRef, LSRolesMask inRoleMask, FSRef* outAppRef, CFURLRef* outAppURL)
    
    #
    #   LSGetApplicationForInfo()
    #
    #   Summary:
    #     Return the application used to open items with particular data.
    #
    #   Discussion:
    #     Consults the binding tables to return the application that would
    #     be used to open items with type, creator, and/or extension as
    #     provided if they were double-clicked in the Finder. This
    #     application will be the default for items like this if one has
    #     been set. If no application is known to LaunchServices suitable
    #     for opening such items, kLSApplicationNotFoundErr will be
    #     returned. Not all three input parameters can be NULL at the same
    #     time nor can both output parameters be NULL at the same time.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inType:
    #       The file type to consider. Can be kLSUnknownType.
    #
    #     inCreator:
    #       The file creator to consider. Can be kLSUnknownCreator.
    #
    #     inExtension:
    #       The file name extension to consider. Can be NULL.
    #
    #     inRoleMask:
    #       Whether to return the editor or viewer for inItemRef. If you
    #       don't care which, use kLSRolesAll.
    #
    #     outAppRef:
    #       Filled in with the FSRef of the application if not NULL.
    #
    #     outAppURL:
    #       Filled in with the CFURLRef of the application if not NULL.
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSGetApplicationForInfo(OSType inType, OSType inCreator, CFStringRef inExtension, LSRolesMask inRoleMask, FSRef* outAppRef, CFURLRef* outAppURL)
    
    #
    #   LSCopyApplicationForMIMEType()
    #
    #   Summary:
    #     Return the application used to handle data with the specified
    #     MIME type.
    #
    #   Discussion:
    #     The returned application URL will be the user's preferred handler
    #     for the MIME type if one has been set. If no user preferred
    #     application has been set, Launch Services will select a default
    #     handler for the MIME type. If no application is known to handle
    #     the MIME type, kLSApplicationNotFoundErr will be returned.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inMIMEType:
    #       The string specifying the MIME type.
    #
    #     inRoleMask:
    #       A role mask that the chosen application must satisfy. Use
    #       kLSRolesAll if the role is not important.
    #
    #     outAppURL:
    #       Receives the copied CFURLRef, which must be released by the
    #       caller.
    #
    #   Availability:
    #     Mac OS X:         in version 10.2 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSCopyApplicationForMIMEType(CFStringRef inMIMEType, LSRolesMask inRoleMask, CFURLRef* outAppURL)
    
    #
    #   LSGetApplicationForURL()
    #
    #   Summary:
    #     Return the application used to open an item.
    #
    #   Discussion:
    #     Consults the binding tables to return the application that would
    #     be used to open inURL if it were double-clicked in the Finder.
    #     This application will be the user-specified override if
    #     appropriate or the default otherwise. If no application is known
    #     to LaunchServices suitable for opening this item,
    #     kLSApplicationNotFoundErr will be returned.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inURL:
    #       The CFURLRef of the item for which the application is requested.
    #
    #     inRoleMask:
    #       Whether to return the editor or viewer for inItemRef. If you
    #       don't care which, use kLSRolesAll.
    #
    #     outAppRef:
    #       Filled in with the FSRef of the application if not NULL.
    #
    #     outAppURL:
    #       Filled in with the CFURLRef of the application if not NULL.
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSGetApplicationForURL(CFURLRef inURL, LSRolesMask inRoleMask, FSRef* outAppRef, CFURLRef* outAppURL)
    
    #
    #   LSFindApplicationForInfo()
    #
    #   Summary:
    #     Locate a specific application.
    #
    #   Discussion:
    #     Returns the application with the corresponding input information.
    #     The registry of applications is consulted first in order of
    #     bundleID, then creator, then name. All comparisons are case
    #     insensitive and 'ties' are decided first by version, then by
    #     native vs. Classic.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inCreator:
    #       The file creator to consider. Can be kLSUnknownCreator.
    #
    #     inBundleID:
    #       The bundle ID to consider. Can be NULL.
    #
    #     inName:
    #       The name to consider. Can be NULL. Must include any extensions
    #       that are part of the file system name, e.g. '.app'.
    #
    #     outAppRef:
    #       Filled in with the FSRef of the application if not NULL.
    #
    #     outAppURL:
    #       Filled in with the CFURLRef of the application if not NULL.
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSFindApplicationForInfo(OSType inCreator, CFStringRef inBundleID, CFStringRef inName,   FSRef* outAppRef, CFURLRef* outAppURL)
    
    #
    #   LSCanRefAcceptItem()
    #
    #   Summary:
    #     Determine whether an item can accept another item.
    #
    #   Discussion:
    #     Returns in outAcceptsItem whether inTargetRef can accept
    #     inItemFSRef as in a drag and drop operation. If inRoleMask is
    #     other than kLSRolesAll then make sure inTargetRef claims to
    #     fulfill the requested role.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inItemFSRef:
    #       FSRef of the item about which acceptance is requested.
    #
    #     inTargetRef:
    #       FSRef of the potential target.
    #
    #     inRoleMask:
    #       The role(s) the target must claim in order to consider
    #       acceptance.
    #
    #     inFlags:
    #       Use kLSAcceptDefault.
    #
    #     outAcceptsItem:
    #       Filled in with result. Must not be NULL.
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSCanRefAcceptItem(FSRef* inItemFSRef, FSRef* inTargetRef, LSRolesMask inRoleMask, LSAcceptanceFlags inFlags, Boolean* outAcceptsItem)
    
    #
    #   LSCanURLAcceptURL()
    #
    #   Summary:
    #     Determine whether an item can accept another item.
    #
    #   Discussion:
    #     Returns in outAcceptsItem whether inTargetURL can accept
    #     inItemURL as in a drag and drop operation. If inRoleMask is other
    #     than kLSRolesAll then make sure inTargetRef claims to fulfill the
    #     requested role.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inItemURL:
    #       CFURLRef of the item about which acceptance is requested.
    #
    #     inTargetURL:
    #       CFURLRef of the potential target.
    #
    #     inRoleMask:
    #       The role(s) the target must claim in order to consider
    #       acceptance.
    #
    #     inFlags:
    #       Use kLSAcceptDefault.
    #
    #     outAcceptsItem:
    #       Filled in with result. Must not be NULL.
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSCanURLAcceptURL(CFURLRef inItemURL, CFURLRef inTargetURL, LSRolesMask inRoleMask, LSAcceptanceFlags inFlags, Boolean* outAcceptsItem)
    
    #
    #   LSOpenFSRef()
    #
    #   Summary:
    #     Open an application, document, or folder.
    #
    #   Discussion:
    #     Opens applications, documents, and folders. Applications are
    #     opened via an 'oapp' or 'rapp' event. Documents are opened in
    #     their user-overridden or default applications as appropriate.
    #     Folders are opened in the Finder. Use the more specific
    #     LSOpenFromRefSpec for more control over launching.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inRef:
    #       The FSRef of the item to launch.
    #
    #     outLaunchedRef:
    #       The FSRef of the item actually launched. For inRefs that are
    #       documents, outLaunchedRef will be the application used to
    #       launch the document. Can be NULL.
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSOpenFSRef(FSRef* inRef, FSRef* outLaunchedRef)
    
    #
    #   LSOpenCFURLRef()
    #
    #   Summary:
    #     Open an application, document, or folder.
    #
    #   Discussion:
    #     Opens applications, documents, and folders. Applications are
    #     opened via an 'oapp' or 'rapp' event. Documents are opened in
    #     their user-overridden or default applications as appropriate.
    #     Folders are opened in the Finder. Use the more specific
    #     LSOpenFromURLSpec for more control over launching.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inURL:
    #       The CFURLRef of the item to launch.
    #
    #     outLaunchedURL:
    #       The CFURLRef of the item actually launched. For inURLs that are
    #       documents, outLaunchedURL will be the application used to
    #       launch the document. Can be NULL.
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSOpenCFURLRef(CFURLRef inURL, CFURLRef* outLaunchedURL)
    
    #
    #   LSOpenFromRefSpec()
    #
    #   Summary:
    #     Opens an application or one or more documents or folders.
    #
    #   Discussion:
    #     Opens applications, documents, and folders.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inLaunchSpec:
    #       The specification of what to launch and how to launch it.
    #
    #     outLaunchedRef:
    #       The FSRef of the item actually launched. For inRefs that are
    #       documents, outLaunchedRef will be the application used to
    #       launch the document. Can be NULL.
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSOpenFromRefSpec(LSLaunchFSRefSpec* inLaunchSpec, FSRef* outLaunchedRef)
    
    #
    #   LSOpenFromURLSpec()
    #
    #   Summary:
    #     Opens an application or one or more documents or folders.
    #
    #   Discussion:
    #     Opens applications, documents, and folders.
    #
    #   Mac OS X threading:
    #     Thread safe since version 10.2
    #
    #   Parameters:
    #
    #     inLaunchSpec:
    #       The specification of what to launch and how to launch it.
    #
    #     outLaunchedURL:
    #       The CFURLRef of the item actually launched. For inURLs that are
    #       documents, outLaunchedURL will be the application used to
    #       launch the document. Can be NULL.
    #
    #   Availability:
    #     Mac OS X:         in version 10.0 and later in ApplicationServices.framework
    #     CarbonLib:        not available in CarbonLib 1.x
    #     Non-Carbon CFM:   not available
    
    cdef OSStatus LSOpenFromURLSpec(LSLaunchURLSpec* inLaunchSpec, CFURLRef* outLaunchedURL)
