import unittest
import os
from LaunchServices import *

class LaunchServicesTestCase(unittest.TestCase):
    def testHelperFunctions(self):
        s = 'test'
        self.assertEquals(s, CFStringFromObject(s).toPython())
        self.assertEquals(s, CFStringFromObject(CFStringFromObject(s)).toPython())
        p = u'/'
        u = u'file://localhost/'
        self.assertEquals(u, PathToURL(p))
        self.assertEquals(u, PathToURL(p))
        self.assertEquals(u, PathToURL(p))
        self.assertEquals(p, URLToPath(u))
        self.assertEquals(p, URLToPath(u))
        self.assertEquals(p, URLToPath(u))

    def testGetItemInfo(self):
        app = '/Applications/iTunes.app'
        def test(info):
            self.assertEquals(info.creator, 'hook')
            self.assertEquals(info.extension, 'app')
            self.assertEquals(info.filetype, 'APPL')
            # iconFileName and kindID don't appear to be useful in 10.2
            # so I won't test them
            self.assert_(kLSItemInfoIsNativeApp in info.flags)
            self.assert_(kLSItemInfoIsPackage in info.flags)
            self.assert_(kLSItemInfoIsApplication in info.flags)
            self.assert_(kLSItemInfoIsContainer in info.flags)
            self.assert_(kLSItemInfoAppIsScriptable in info.flags)
            self.assert_(kLSItemInfoExtensionIsHidden in info.flags)
        test(GetInfoForPath(app, kLSRequestAllInfo))
        test(GetInfoForURL(PathToURL(app), kLSRequestAllInfo))

    def testGetExtensionInfoForPath(self):
        app = '/Applications/iTunes.app'
        self.assertEquals(os.path.splitext(app), GetExtensionInfoForPath(app))

    def testGetDisplayName(self):
        app = '/applications/iTunes.app'
        self.assertEquals('iTunes', GetDisplayNameForPath(app))
        self.assertEquals('iTunes', GetDisplayNameForURL(PathToURL(app)))
    
    # SetExtensionHidden doesn't seem to do anything, no test yet.

    def testGetKindStringForPath(self):
        app = '/'
        self.assertEquals('Volume', GetKindStringForPath(app))
        self.assertEquals('Volume', GetKindStringForURL(PathToURL(app)))

    def testGetKindString(self):
        app = 'Portable Network Graphics Image'
        self.assertEquals(app, GetKindStringForTypeInfo(filetype='PNGf'))
        self.assertEquals(app, GetKindStringForTypeInfo(extension='png'))
        self.assertEquals(app, GetKindStringForMIMEType('image/png'))

    def testGetApplication(self):
        app = '/System/Library/CoreServices/Finder.app'
        app2 = '/System/Library/CoreServices/Help Viewer.app'
        app3 = '/Applications/Chess.app'
        self.assertEquals(app, GetApplicationPathForPath('/Library/Documentation/Help'))
        self.assertEquals(app2, GetApplicationPathForPath('/Library/Documentation/Help/MacHelp.help'))
        self.assertEquals(app2, GetApplicationPathForInfo(extension='help'))
        self.assertEquals(app3, GetApplicationPathForInfo(extension='chess'))
        self.assertEquals(PathToURL(app).rstrip('/'), GetApplicationURLForURL(PathToURL('/Library/Documentation/Help')).rstrip('/'))
        self.assertEquals(PathToURL(app2).rstrip('/'), GetApplicationURLForURL(PathToURL('/Library/Documentation/Help/MacHelp.help')).rstrip('/'))
        self.assertEquals(PathToURL('/Applications/Utilities/StuffIt Expander.app').rstrip('/'), GetApplicationURLForMIMEType('application/x-stuffit').rstrip('/'))
        self.assertEquals(app, FindApplicationPath(bundle='com.apple.finder'))
        self.assertEquals(app, FindApplicationPath(creator='MACS'))
        self.assertEquals(app, FindApplicationPath(name='Finder.app'))
        self.assertEquals(PathToURL(app).rstrip('/'), FindApplicationURL(bundle='com.apple.finder').rstrip('/'))
        self.assertEquals(PathToURL(app).rstrip('/'), FindApplicationURL(creator='MACS').rstrip('/'))
        self.assertEquals(PathToURL(app).rstrip('/'), FindApplicationURL(name='Finder.app').rstrip('/'))

    def skipped_testCanApplicationPath(self):
        app = '/System/Library/CoreServices/Help Viewer.app'
        # I have NO IDEA WHY THIS DOESN'T WORK!
        self.assertEquals(True, CanApplicationPathAcceptPath(app, '/Library/Documentation/Help/MacHelp.help'))
        self.assertEquals(False, CanApplicationPathAcceptPath(app, '/Library/Documentation/Help/'))

    def testCanApplicationURL(self):
        app = PathToURL('/System/Library/CoreServices/Help Viewer.app').rstrip('/')
        self.assertEquals(True, CanApplicationURLAcceptURL(app, PathToURL('/Library/Documentation/Help/MacHelp.help/')))
        self.assertEquals(False, CanApplicationURLAcceptURL(app, PathToURL('/Library/Documentation/Help')))

if __name__ == '__main__':
    unittest.main()
